@@ -332,7 +332,7 @@ setMethodS3("getKnownSubclasses", "Class", function(this, sort=TRUE, ...) {
 
 ##  # (a) Search loaded namespaces
 ##  for (ns in loadedNamespaces()) {
-##    envir <- asNamespace(ns);
+##    envir <- getNamespace(ns);
 ##    classesT <- getKnownSubclassesInEnvironment(name, envir=envir);
 ##    classes <- c(classes, classesT);
 ##  }
@@ -444,7 +444,7 @@ setMethodS3("isAbstract", "Class", function(this, ...) {
   methods <- unlist(methods);
   methods <- methods[nchar(methods) > 0L];
   for (method in methods) {
-    mtd <- .findS3Method(method, envir=environment(this));
+    mtd <- .getS3Method(method, envir=environment(this));
     if (is.element("abstract", attr(mtd, "modifiers")))
       return(TRUE);
   }
@@ -493,7 +493,7 @@ setMethodS3("isStatic", "Class", function(this, ...) {
   methods <- unlist(methods);
   methods <- methods[nchar(methods) > 0L];
   for (method in methods) {
-    mtd <- .findS3Method(method, envir=environment(this));
+    mtd <- .getS3Method(method, envir=environment(this));
     if (is.element("static", attr(mtd, "modifiers")))
       return(TRUE);
   }
@@ -675,7 +675,7 @@ setMethodS3("isDeprecated", "Class", function(this, ...) {
 # @synopsis
 #
 # \arguments{
-#   \item{...}{Not used.}
+#   \item{...}{Optional arguments passed to internal lookup function.}
 # }
 #
 # \value{
@@ -697,17 +697,8 @@ setMethodS3("isDeprecated", "Class", function(this, ...) {
 # @keyword programming
 # @keyword methods
 #*/###########################################################################
-setMethodS3("forName", "Class", function(this, name, ...) {
-  # TO DO/FIX ME: This part only works when packages are attached.
-  # /HB 2013-10-08
-  if (!exists(name, mode="function")) {
-    throw("No such class: ", name);
-  }
-  fcn <- get(name, mode="function");
-  if (!inherits(fcn, "Class")) {
-    throw("Can not find Class: ", name);
-  }
-  fcn;
+setMethodS3("forName", "Class", function(static, name, ...) {
+  .getClassByName(name, ..., mustExist=TRUE);
 }, static=TRUE) # forName()
 
 
@@ -1083,7 +1074,7 @@ setMethodS3("getMethods", "Class", function(this, private=FALSE, deprecated=TRUE
 ##    # (a) Search loaded namespaces
 ##    if (is.element("ns", where)) {
 ##      for (ns in loadedNamespaces()) {
-##        envir <- asNamespace(ns);
+##        envir <- getNamespace(ns);
 ##        res <- findS3MethodsByEnvironment(classNames, envir=envir, exclMods=exclMods, res=res);
 ##      }
 ##    }
@@ -1308,7 +1299,7 @@ setMethodS3("getDetails", "Class", function(this, private=FALSE, ...) {
         isPrivate <- (regexpr("^\\.", methodNames) != -1L);
         modifiers[isPrivate] <- "private";
         for (kk in seq(along=methodNames)) {
-          fcn <- .findS3Method(methods[kk], envir=envir, mustExist=TRUE);
+          fcn <- .getS3Method(methods[kk], envir=envir, mustExist=TRUE);
           fcnModifiers <- attr(fcn, "modifiers");
           if (is.element("protected", fcnModifiers)) {
             modifiers[kk] <- "protected";
@@ -1418,7 +1409,7 @@ setMethodS3("$", "Class", function(this, name) {
     getMethodNames <- paste("get", capitalizedName, ".", class(static), sep="");
     envir <- environment(static);
     for (getMethodName in getMethodNames) {
-      fcn <- .findS3Method(getMethodName, envir=envir, mustExist=FALSE);
+      fcn <- .getS3Method(getMethodName, envir=envir, mustExist=FALSE);
       if (!is.null(fcn)) {
         ref <- static;
         attr(ref, "disableGetMethods") <- TRUE;
@@ -1445,7 +1436,7 @@ setMethodS3("$", "Class", function(this, name) {
   envir <- environment(static);
   methodNames <- paste(name, class(static), sep=".");
   for (methodName in methodNames) {
-    mtd <- .findS3Method(methodName, envir=envir, mustExist=FALSE);
+    mtd <- .getS3Method(methodName, envir=envir, mustExist=FALSE);
     if (!is.null(mtd)) {
       # Using explicit UseMethod() code
       code <- sprintf("function(...) \"%s\"(static, ...)", name);
@@ -1555,7 +1546,7 @@ setMethodS3("$<-", "Class", function(this, name, value) {
     setMethodNames <- paste("set", capitalizedName, ".", class(static), sep="");
     envir <- environment(static);
     for (setMethodName in setMethodNames) {
-      mtd <- .findS3Method(setMethodName, envir=envir, mustExist=FALSE);
+      mtd <- .getS3Method(setMethodName, envir=envir, mustExist=FALSE);
       if (!is.null(mtd)) {
         ref <- static;
         attr(ref, "disableSetMethods") <- TRUE;
@@ -1593,6 +1584,8 @@ setMethodS3("[[<-", "Class", function(this, name, value) {
 
 ############################################################################
 # HISTORY:
+# 2014-01-05
+# o CLEANUP: Now static method Class$forName() utilizes .getClassByName().
 # 2013-08-20
 # o Now getPackage() for Object first searches the namesspace of the
 #   Class object and then the attached ("loaded") packages.
