@@ -1,6 +1,13 @@
 # Detach the 'R.oo' attached in file 030.ObjectClassFunctions.R
 if (is.element("R.oo", search())) detach("R.oo");
 
+.onUnload <- function(libpath) {
+##  message("R.oo::.onUnload()");
+  # Force finalize() on Object:s
+  base::gc();
+} # .onUnload()
+
+
 .onLoad <- function(libname, pkgname) {
   ns <- getNamespace(pkgname);
 
@@ -18,13 +25,14 @@ if (is.element("R.oo", search())) detach("R.oo");
 
 
 .onAttach <- function(libname, pkgname) {
-  # Set default 'properties' argument for ll(), if missing
-  key <- paste(pkgname, "::ll/properties", sep="");
-  if (!is.element(key, names(options()))) {
-    args <- list(c("data.class", "dimension", "objectSize"));
-    names(args) <- key;
-    do.call(options, args=args);
-  }
   pkg <- get(pkgname, envir=getNamespace(pkgname));
   startupMessage(pkg);
 } # .onAttach()
+
+
+
+############################################################################
+# HISTORY:
+# 2014-02-21
+# o Added .onUnload() which calls the garbage collector.
+############################################################################
