@@ -1,3 +1,4 @@
+library("R.methodsS3")
 library("R.oo")
 
 lotsOfParsing <- function(code="y <- 1:3") {
@@ -10,7 +11,7 @@ setConstructorS3("MyClass", function(a=1:10) {
 
 setMethodS3("finalize", "MyClass", function(this, ...) {
   cat("finalize...\n")
-  str(sys.calls())
+  utils::str(sys.calls())
   cat("finalize...done\n")
 })
 
